# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_stubs/modbus_iface.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgrpc_stubs/modbus_iface.proto\x12\x0cmodbus_iface\"\xd5\x01\n\tbusStatus\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\x08\x12=\n\x0fserial_settings\x18\x03 \x01(\x0b\x32\x1f.modbus_iface.serialBusSettingsH\x00\x88\x01\x01\x12\x41\n\x11\x65thernet_settings\x18\x04 \x01(\x0b\x32!.modbus_iface.ethernetBusSettingsH\x01\x88\x01\x01\x42\x12\n\x10_serial_settingsB\x14\n\x12_ethernet_settings\"\xb0\x01\n\x0eresponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rresponse_code\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10response_message\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\nbus_status\x18\x04 \x03(\x0b\x32\x17.modbus_iface.busStatusB\x10\n\x0e_response_codeB\x13\n\x11_response_message\"\x89\x01\n\x14serverResponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rresponse_code\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10response_message\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_response_codeB\x13\n\x11_response_message\"#\n\x10testCommsRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\"\\\n\x11testCommsResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x10\n\x08response\x18\x02 \x01(\t\"\xeb\x01\n\x11serialBusSettings\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61ud\x18\x02 \x01(\x05\x12\x1a\n\rmodbus_method\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdata_bits\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x13\n\x06parity\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tstop_bits\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07timeout\x18\x07 \x01(\x02H\x04\x88\x01\x01\x42\x10\n\x0e_modbus_methodB\x0c\n\n_data_bitsB\t\n\x07_parityB\x0c\n\n_stop_bitsB\n\n\x08_timeout\"\x7f\n\x13\x65thernetBusSettings\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x1a\n\rmodbus_method\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07timeout\x18\x04 \x01(\x02H\x01\x88\x01\x01\x42\x10\n\x0e_modbus_methodB\n\n\x08_timeout\"\xac\x01\n\x0eopenBusRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12:\n\x0fserial_settings\x18\x02 \x01(\x0b\x32\x1f.modbus_iface.serialBusSettingsH\x00\x12>\n\x11\x65thernet_settings\x18\x03 \x01(\x0b\x32!.modbus_iface.ethernetBusSettingsH\x00\x42\x0e\n\x0c\x62us_settings\"X\n\x0fopenBusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"\x10\n\x0elistBusRequest\"u\n\x0flistBusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12+\n\nbus_status\x18\x02 \x03(\x0b\x32\x17.modbus_iface.busStatus\"\"\n\x10\x62usStatusRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\"w\n\x11\x62usStatusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12+\n\nbus_status\x18\x02 \x01(\x0b\x32\x17.modbus_iface.busStatus\"!\n\x0f\x63loseBusRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\"Y\n\x10\x63loseBusResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\"o\n\x13readRegisterRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tmodbus_id\x18\x02 \x01(\x05\x12\x15\n\rregister_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\"t\n\x14readRegisterResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x15\n\rresponse_code\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x05\"q\n\x14writeRegisterRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tmodbus_id\x18\x02 \x01(\x05\x12\x15\n\rregister_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\x0e\n\x06values\x18\x05 \x03(\x05\"e\n\x15writeRegisterResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x15\n\rresponse_code\x18\x02 \x01(\x05\"z\n\x1cscheduleWriteRegisterRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x15\n\rregister_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\x12\x12\n\ndelay_secs\x18\x05 \x01(\x05\"z\n\x1dscheduleWriteRegisterResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x12\n\ndelay_secs\x18\x03 \x01(\x05\"\x8e\x01\n\x1freadRegisterSubscriptionRequest\x12\x0e\n\x06\x62us_id\x18\x01 \x01(\t\x12\x11\n\tmodbus_id\x18\x02 \x01(\x05\x12\x15\n\rregister_type\x18\x03 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\x05\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x11\n\tpoll_secs\x18\x06 \x01(\x05\"\x90\x01\n readRegisterSubscriptionResponse\x12\x35\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\x1c.modbus_iface.responseHeader\x12\x0e\n\x06\x62us_id\x18\x02 \x01(\t\x12\x15\n\rresponse_code\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\"\xca\x01\n\x13\x63reateServerRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x11\n\x04port\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04host\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x11holding_registers\x18\x04 \x03(\x05\x12\x17\n\x0finput_registers\x18\x05 \x03(\x05\x12\r\n\x05\x63oils\x18\x06 \x03(\x08\x12\x17\n\x0f\x64iscrete_inputs\x18\x07 \x03(\x08\x12\x11\n\tmodbus_id\x18\x08 \x01(\x05\x42\x07\n\x05_portB\x07\n\x05_host\"e\n\x14\x63reateServerResponse\x12;\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\".modbus_iface.serverResponseHeader\x12\x10\n\x08response\x18\x02 \x01(\t\"\x13\n\x11listServerRequest\"b\n\x12listServerResponse\x12;\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\".modbus_iface.serverResponseHeader\x12\x0f\n\x07servers\x18\x02 \x03(\t\"\"\n\x12\x63loseServerRequest\x12\x0c\n\x04port\x18\x01 \x01(\x05\"`\n\x13\x63loseServerResponse\x12;\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\".modbus_iface.serverResponseHeader\x12\x0c\n\x04port\x18\x02 \x01(\x05\"a\n\x19setServerRegistersRequest\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x15\n\rfunction_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x03(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\"Y\n\x1asetServerRegistersResponse\x12;\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\".modbus_iface.serverResponseHeader\"`\n\x19getServerRegistersRequest\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x15\n\rfunction_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\x05\x12\r\n\x05\x63ount\x18\x04 \x01(\x05\"i\n\x1agetServerRegistersResponse\x12;\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\".modbus_iface.serverResponseHeader\x12\x0e\n\x06values\x18\x02 \x03(\x05\"z\n\x1escheduleServerRegistersRequest\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x15\n\rfunction_code\x18\x02 \x01(\x05\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x05\x12\x12\n\ndelay_secs\x18\x05 \x01(\x02\"^\n\x1fscheduleServerRegistersResponse\x12;\n\x0fresponse_header\x18\x01 \x01(\x0b\x32\".modbus_iface.serverResponseHeader2\x8b\x0b\n\x0bmodbusIface\x12N\n\ttestComms\x12\x1e.modbus_iface.testCommsRequest\x1a\x1f.modbus_iface.testCommsResponse\"\x00\x12H\n\x07openBus\x12\x1c.modbus_iface.openBusRequest\x1a\x1d.modbus_iface.openBusResponse\"\x00\x12H\n\x07listBus\x12\x1c.modbus_iface.listBusRequest\x1a\x1d.modbus_iface.listBusResponse\"\x00\x12N\n\tbusStatus\x12\x1e.modbus_iface.busStatusRequest\x1a\x1f.modbus_iface.busStatusResponse\"\x00\x12K\n\x08\x63loseBus\x12\x1d.modbus_iface.closeBusRequest\x1a\x1e.modbus_iface.closeBusResponse\"\x00\x12X\n\rreadRegisters\x12!.modbus_iface.readRegisterRequest\x1a\".modbus_iface.readRegisterResponse\"\x00\x12[\n\x0ewriteRegisters\x12\".modbus_iface.writeRegisterRequest\x1a#.modbus_iface.writeRegisterResponse\"\x00\x12s\n\x16scheduleWriteRegisters\x12*.modbus_iface.scheduleWriteRegisterRequest\x1a+.modbus_iface.scheduleWriteRegisterResponse\"\x00\x12}\n\x18readRegisterSubscription\x12-.modbus_iface.readRegisterSubscriptionRequest\x1a..modbus_iface.readRegisterSubscriptionResponse\"\x00\x30\x01\x12W\n\x0c\x63reateServer\x12!.modbus_iface.createServerRequest\x1a\".modbus_iface.createServerResponse\"\x00\x12Q\n\nlistServer\x12\x1f.modbus_iface.listServerRequest\x1a .modbus_iface.listServerResponse\"\x00\x12T\n\x0b\x63loseServer\x12 .modbus_iface.closeServerRequest\x1a!.modbus_iface.closeServerResponse\"\x00\x12i\n\x12setServerRegisters\x12\'.modbus_iface.setServerRegistersRequest\x1a(.modbus_iface.setServerRegistersResponse\"\x00\x12i\n\x12getServerRegisters\x12\'.modbus_iface.getServerRegistersRequest\x1a(.modbus_iface.getServerRegistersResponse\"\x00\x12x\n\x17scheduleServerRegisters\x12,.modbus_iface.scheduleServerRegistersRequest\x1a-.modbus_iface.scheduleServerRegistersResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_stubs.modbus_iface_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUSSTATUS']._serialized_start=48
  _globals['_BUSSTATUS']._serialized_end=261
  _globals['_RESPONSEHEADER']._serialized_start=264
  _globals['_RESPONSEHEADER']._serialized_end=440
  _globals['_SERVERRESPONSEHEADER']._serialized_start=443
  _globals['_SERVERRESPONSEHEADER']._serialized_end=580
  _globals['_TESTCOMMSREQUEST']._serialized_start=582
  _globals['_TESTCOMMSREQUEST']._serialized_end=617
  _globals['_TESTCOMMSRESPONSE']._serialized_start=619
  _globals['_TESTCOMMSRESPONSE']._serialized_end=711
  _globals['_SERIALBUSSETTINGS']._serialized_start=714
  _globals['_SERIALBUSSETTINGS']._serialized_end=949
  _globals['_ETHERNETBUSSETTINGS']._serialized_start=951
  _globals['_ETHERNETBUSSETTINGS']._serialized_end=1078
  _globals['_OPENBUSREQUEST']._serialized_start=1081
  _globals['_OPENBUSREQUEST']._serialized_end=1253
  _globals['_OPENBUSRESPONSE']._serialized_start=1255
  _globals['_OPENBUSRESPONSE']._serialized_end=1343
  _globals['_LISTBUSREQUEST']._serialized_start=1345
  _globals['_LISTBUSREQUEST']._serialized_end=1361
  _globals['_LISTBUSRESPONSE']._serialized_start=1363
  _globals['_LISTBUSRESPONSE']._serialized_end=1480
  _globals['_BUSSTATUSREQUEST']._serialized_start=1482
  _globals['_BUSSTATUSREQUEST']._serialized_end=1516
  _globals['_BUSSTATUSRESPONSE']._serialized_start=1518
  _globals['_BUSSTATUSRESPONSE']._serialized_end=1637
  _globals['_CLOSEBUSREQUEST']._serialized_start=1639
  _globals['_CLOSEBUSREQUEST']._serialized_end=1672
  _globals['_CLOSEBUSRESPONSE']._serialized_start=1674
  _globals['_CLOSEBUSRESPONSE']._serialized_end=1763
  _globals['_READREGISTERREQUEST']._serialized_start=1765
  _globals['_READREGISTERREQUEST']._serialized_end=1876
  _globals['_READREGISTERRESPONSE']._serialized_start=1878
  _globals['_READREGISTERRESPONSE']._serialized_end=1994
  _globals['_WRITEREGISTERREQUEST']._serialized_start=1996
  _globals['_WRITEREGISTERREQUEST']._serialized_end=2109
  _globals['_WRITEREGISTERRESPONSE']._serialized_start=2111
  _globals['_WRITEREGISTERRESPONSE']._serialized_end=2212
  _globals['_SCHEDULEWRITEREGISTERREQUEST']._serialized_start=2214
  _globals['_SCHEDULEWRITEREGISTERREQUEST']._serialized_end=2336
  _globals['_SCHEDULEWRITEREGISTERRESPONSE']._serialized_start=2338
  _globals['_SCHEDULEWRITEREGISTERRESPONSE']._serialized_end=2460
  _globals['_READREGISTERSUBSCRIPTIONREQUEST']._serialized_start=2463
  _globals['_READREGISTERSUBSCRIPTIONREQUEST']._serialized_end=2605
  _globals['_READREGISTERSUBSCRIPTIONRESPONSE']._serialized_start=2608
  _globals['_READREGISTERSUBSCRIPTIONRESPONSE']._serialized_end=2752
  _globals['_CREATESERVERREQUEST']._serialized_start=2755
  _globals['_CREATESERVERREQUEST']._serialized_end=2957
  _globals['_CREATESERVERRESPONSE']._serialized_start=2959
  _globals['_CREATESERVERRESPONSE']._serialized_end=3060
  _globals['_LISTSERVERREQUEST']._serialized_start=3062
  _globals['_LISTSERVERREQUEST']._serialized_end=3081
  _globals['_LISTSERVERRESPONSE']._serialized_start=3083
  _globals['_LISTSERVERRESPONSE']._serialized_end=3181
  _globals['_CLOSESERVERREQUEST']._serialized_start=3183
  _globals['_CLOSESERVERREQUEST']._serialized_end=3217
  _globals['_CLOSESERVERRESPONSE']._serialized_start=3219
  _globals['_CLOSESERVERRESPONSE']._serialized_end=3315
  _globals['_SETSERVERREGISTERSREQUEST']._serialized_start=3317
  _globals['_SETSERVERREGISTERSREQUEST']._serialized_end=3414
  _globals['_SETSERVERREGISTERSRESPONSE']._serialized_start=3416
  _globals['_SETSERVERREGISTERSRESPONSE']._serialized_end=3505
  _globals['_GETSERVERREGISTERSREQUEST']._serialized_start=3507
  _globals['_GETSERVERREGISTERSREQUEST']._serialized_end=3603
  _globals['_GETSERVERREGISTERSRESPONSE']._serialized_start=3605
  _globals['_GETSERVERREGISTERSRESPONSE']._serialized_end=3710
  _globals['_SCHEDULESERVERREGISTERSREQUEST']._serialized_start=3712
  _globals['_SCHEDULESERVERREGISTERSREQUEST']._serialized_end=3834
  _globals['_SCHEDULESERVERREGISTERSRESPONSE']._serialized_start=3836
  _globals['_SCHEDULESERVERREGISTERSRESPONSE']._serialized_end=3930
  _globals['_MODBUSIFACE']._serialized_start=3933
  _globals['_MODBUSIFACE']._serialized_end=5352
# @@protoc_insertion_point(module_scope)
